cgexplore.terms.MartiniAngleRange
=================================

.. currentmodule:: cgexplore.terms

.. autoclass:: MartiniAngleRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~MartiniAngleRange.yield_angles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MartiniAngleRange.type1
      ~MartiniAngleRange.type2
      ~MartiniAngleRange.type3
      ~MartiniAngleRange.element1
      ~MartiniAngleRange.element2
      ~MartiniAngleRange.element3
      ~MartiniAngleRange.funct
      ~MartiniAngleRange.angles
      ~MartiniAngleRange.angle_ks
   
   